==> sumus-6.4.5-sources.jar: io/intino/sumus/graph/StackedIndicator.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class StackedIndicator extends io.intino.sumus.graph.Indicator implements io.intino.tara.magritte.tags.Component, io.intino.tara.magritte.tags.Terminal {

	protected java.util.List<io.intino.sumus.graph.MeasureIndicator> measureIndicatorList = new java.util.ArrayList<>();

	public StackedIndicator(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator> measureIndicatorList() {
		return java.util.Collections.unmodifiableList(measureIndicatorList);
	}

	public io.intino.sumus.graph.MeasureIndicator measureIndicator(int index) {
		return measureIndicatorList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator> measureIndicatorList(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator> predicate) {
		return measureIndicatorList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(measureIndicatorList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("MeasureIndicator")) this.measureIndicatorList.add(node.as(io.intino.sumus.graph.MeasureIndicator.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("MeasureIndicator")) this.measureIndicatorList.remove(node.as(io.intino.sumus.graph.MeasureIndicator.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Indicator.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.MeasureIndicator measureIndicator(java.lang.String label, io.intino.sumus.graph.AbstractMetric.Unit unit) {
		    io.intino.sumus.graph.MeasureIndicator newElement = core$().graph().concept(io.intino.sumus.graph.MeasureIndicator.class).createNode(name, core$()).as(io.intino.sumus.graph.MeasureIndicator.class);
			newElement.core$().set(newElement, "label", java.util.Collections.singletonList(label));
			newElement.core$().set(newElement, "unit", java.util.Collections.singletonList(unit));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void measureIndicator(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator> filter) {
			new java.util.ArrayList<>(measureIndicatorList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/graph/StackedIndicator.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class StackedIndicator extends io.intino.sumus.graph.Indicator implements io.intino.tara.magritte.tags.Component, io.intino.tara.magritte.tags.Terminal {

	protected java.util.List<io.intino.sumus.graph.MeasureIndicator> measureIndicatorList = new java.util.ArrayList<>();

	public StackedIndicator(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator> measureIndicatorList() {
		return java.util.Collections.unmodifiableList(measureIndicatorList);
	}

	public io.intino.sumus.graph.MeasureIndicator measureIndicator(int index) {
		return measureIndicatorList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.MeasureIndicator> measureIndicatorList(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator> predicate) {
		return measureIndicatorList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(measureIndicatorList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("MeasureIndicator")) this.measureIndicatorList.add(node.as(io.intino.sumus.graph.MeasureIndicator.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("MeasureIndicator")) this.measureIndicatorList.remove(node.as(io.intino.sumus.graph.MeasureIndicator.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Indicator.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.MeasureIndicator measureIndicator(java.lang.String label, io.intino.sumus.graph.AbstractMetric.Unit unit) {
		    io.intino.sumus.graph.MeasureIndicator newElement = core$().graph().concept(io.intino.sumus.graph.MeasureIndicator.class).createNode(this.name, core$()).as(io.intino.sumus.graph.MeasureIndicator.class);
			newElement.core$().set(newElement, "label", java.util.Collections.singletonList(label));
			newElement.core$().set(newElement, "unit", java.util.Collections.singletonList(unit));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void measureIndicator(java.util.function.Predicate<io.intino.sumus.graph.MeasureIndicator> filter) {
			new java.util.ArrayList<>(measureIndicatorList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
